@@ -1,5 +1,5 @@
 #!/bin/sh
-# @(#) $Id: jpegrotate.sh 302 2019-07-27 17:49:03Z leres $ (XSE)
+# @(#) $Id: jpegrotate.sh 303 2020-03-08 20:05:17Z leres $ (XSE)
 #
 # jpegrotate - rotate jpeg images
 #
@@ -7,13 +7,16 @@
 prog="`basename $0`"
 usage()
 {
-	echo "${prog} [-n] file ...	# auto-rotate using exitags" 1>&2
-	echo "${prog} [-nF] -l file ...	# rotate left" 1>&2
-	echo "${prog} [-nF] -r file ...	# rotate right" 1>&2
-	echo "${prog} [-nF] -f file ...	# rotate 180 (flip)" 1>&2
-	echo "${prog} [-nF] -h file ...	# horizontal" 1>&2
-	echo "${prog} [-nF] -V file ...	# vertical" 1>&2
-	echo "${prog} [-nF] -u file ...	# undo" 1>&2
+	echo "${prog} file ...	# auto-rotate" 1>&2
+	echo "${prog} -l file ...	# rotate left" 1>&2
+	echo "${prog} -r file ...	# rotate right" 1>&2
+	echo "${prog} -f file ...	# rotate 180 (flip)" 1>&2
+	echo "${prog} -h file ...	# horizontal" 1>&2
+	echo "${prog} -V file ...	# vertical" 1>&2
+	echo "${prog} -u file ...	# undo" 1>&2
+	echo "${prog} -n		# dryrun" 1>&2
+	echo "${prog} -F		# force" 1>&2
+	echo "${prog} -O		# override" 1>&2
 	exit 1
 }
 
@@ -25,9 +28,10 @@ dryrun=0
 force=0
 option=""
 status=0
+override=0
 undo=0
 
-args=`getopt FfhlnruV $*`
+args=`getopt FfhlOnruV $*`
 
 if [ $? -ne 0 ]; then
 	usage
@@ -72,6 +76,11 @@ for a do
 		shift
 		;;
 
+	-O)
+		override=1
+		shift
+		;;
+
 	-V)
 		option="-f"
 		automatic=0
@@ -94,6 +103,16 @@ if [ -n "${option}" -a ${undo} -ne 0 ]; then
 	usage
 fi
 
+if [ "${force}" -ne 0 -a ${override} -ne 0 ]; then
+	echo "${prog}: Cannot use both -F (force) and -O (override)" 1>&2
+	exit 1
+fi
+
+if [ -z "${option}" -a ${override} -ne 0 ]; then
+	echo "${prog}: Cannot use automatic with -O (override)" 1>&2
+	exit 1
+fi
+
 if [ ${automatic} -ne 0 ]; then
 	option="-a"
 fi
@@ -190,12 +209,12 @@ while [ $# -gt 0 ]; do
 	esac
 
 	r="`echo ${f} | sed -e 's/r*\(\.[Jj][Pp][Gg]\)$/r\1/'`"
-	if [ "${f}" = "${r}" -a ${force} -eq 0 ]; then
-		echo "${prog}: ${f} already rotated? (skipping)"
+	if [ "${f}" = "${r}" -a ${override} -eq 0 ]; then
+		echo "${prog}: ${f} already rotated? (use -O to override)"
 		status=1
 		continue
 	fi
-	if [ -r ${r} -a ${force} -eq 0 ]; then
+	if [ -r ${r} -a ${override} -eq 0 ]; then
 		echo "${prog}: ${r} already exists, skipping ${f}"
 		status=1
 		continue
@@ -286,12 +305,22 @@ while [ $# -gt 0 ]; do
 	fi
 
 	# Do this last in case exiftran fails
-	execute "mv ${f} ${o}"
+	if [ ${override} -eq 0 ]; then
+		# Don't keep original when overriding
+		execute "mv ${f} ${o}"
+	else
+		# Pick up timestamps from original
+		o="${o%r\.jpg-}.jpg-"
+	fi
 
 	# Rename temporary then copy access and modified timestamps
 	execute "mv ${t} ${r}"
 	execute "${touch} -r ${o} ${r}"
-	echo "${prog}: ${f} -> ${r}"
+	if [ ${override} -eq 0 ]; then
+		echo "${prog}: ${f} -> ${r}"
+	else
+		echo "${prog}: ${r} (rotated)"
+	fi
 done
 
 exit ${status}
