@@ -1,5 +1,5 @@
 #!/bin/sh
-# @(#) $Id: updatetimestamps.sh 320 2022-12-12 23:21:34Z leres $ (XSE)
+# @(#) $Id: updatetimestamps.sh 321 2023-01-14 21:31:06Z leres $ (XSE)
 #
 # updatetimestamps - image the timestamps section of a webindex.conf file
 #
@@ -11,10 +11,39 @@ t2=/tmp/${prog}.2.$$
 
 trap 'rm -f ${t1} ${t2}; exit 1' 1 2 3 15
 
+usage()
+{
+	echo "usage: ${prog} [-c CONF] [directories]" 1>&2
+	exit 1
+}
+
+args=`getopt c: $*`
+if [ $? -ne 0 ]; then
+	usage
+fi
+
+set -- ${args}
+
 conf="webindex.conf"
 
+for a do
+	case "${a}" in
+
+	-c)
+		conf="$2"
+		shift
+		shift
+		;;
+
+	--)
+		shift
+		break
+		;;
+	esac
+done
+
 if [ ! -r ${conf} ]; then
-	echo "${prog}":" missing ${conf}"
+	echo "${prog}":" config ${conf} missing"
 	exit 1
 fi
 
